/*
 *
 *
 *    baudot.h
 *
 *    Bit patterns for Baudot.
 *
 *    License: GNU General Public License Version 3.0.
 *    
 *    Copyright (C) 2016 by Matthew K. Roberts, KK5JY. All rights reserved.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful, but
 *    WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see: http://www.gnu.org/licenses/
 *
 *
 */

#ifndef __BAUDOT_H
#define __BAUDOT_H

//
//  Define Baudot transformations
//
//  Each definition includes a single start bit (1) on the LSB (right) and
//  implied stop bits (0) on the MSB (left).  Also, the data bits appear
//  to be inverted when compared to most Baudot tables; the bits in these
//  symbols are intended to have an idle TTL voltage level of 0V, making
//  the start bit a high (1) value.
//

// NUL
#define RTTY_NUL (0b111111)
// letter shift
#define RTTY_LS (0b000001)
// figure shift
#define RTTY_FS (0b001001)
// CR
#define RTTY_CR (0b101111)
// LF
#define RTTY_LF (0b111011)
// SP
#define RTTY_SP (0b110111)

// letters
#define RTTY_A (0b111001)
#define RTTY_B (0b001101)
#define RTTY_C (0b100011)
#define RTTY_D (0b101101)
#define RTTY_E (0b111101)
#define RTTY_F (0b100101)
#define RTTY_G (0b001011)
#define RTTY_H (0b010111)
#define RTTY_I (0b110011)
#define RTTY_J (0b101001)
#define RTTY_K (0b100001)
#define RTTY_L (0b011011)
#define RTTY_M (0b000111)
#define RTTY_N (0b100111)
#define RTTY_O (0b001111)
#define RTTY_P (0b010011)
#define RTTY_Q (0b010001)
#define RTTY_R (0b101011)
#define RTTY_S (0b110101)
#define RTTY_T (0b011111)
#define RTTY_U (0b110001)
#define RTTY_V (0b000011)
#define RTTY_W (0b011001)
#define RTTY_X (0b000101)
#define RTTY_Y (0b010101)
#define RTTY_Z (0b011101)

// digits
#define RTTY_0 RTTY_P
#define RTTY_1 RTTY_Q
#define RTTY_2 RTTY_W
#define RTTY_3 RTTY_E
#define RTTY_4 RTTY_R
#define RTTY_5 RTTY_T
#define RTTY_6 RTTY_Y
#define RTTY_7 RTTY_U
#define RTTY_8 RTTY_I
#define RTTY_9 RTTY_O

// selected symbols
#define RTTY_DASH	RTTY_A
#define RTTY_QUOTE	RTTY_S
#define RTTY_DOLLAR	RTTY_D
#define RTTY_BANG	RTTY_F
#define RTTY_AMP	RTTY_G
#define RTTY_HASH	RTTY_H
#define RTTY_PARL	RTTY_K
#define RTTY_PARR	RTTY_L
#define RTTY_PLUS	RTTY_Z
#define RTTY_SLASH	RTTY_X
#define RTTY_SEMI	RTTY_V
#define RTTY_QUES	RTTY_B
#define RTTY_COMMA	RTTY_N
#define RTTY_FSTOP	RTTY_M
#define RTTY_COLON	RTTY_C

#endif // EOF
